from distutils.core import setup

setup(
    name="clu_codes_nester",
    version="1.4.0",
    py_modules=["clu_codes_nester"],
    author="clu_codes",
    author_email="clu.codes@gmail.com",
    description="A simple printer of nested lists",
)


# to update or build, use command 'python3 setup.py sdist upload'
